@@ -13,30 +13,38 @@ from typing import (
 )
 from zipfile import ZipFile
 
-from arkowrapper import ArkoWrapper
+from pydantic import (
+    AnyHttpUrl,
+    Field,
+    PrivateAttr,
+)
+from requests import Session
+from typing_extensions import Literal
+from yarl import URL
+
 from async_pixiv.error import ArtWorkTypeError
 from async_pixiv.model._base import (
     PixivModel,
     null_dict_validator,
 )
 from async_pixiv.model.other import (
+    AIType,
     ImageUrl,
     Series,
     Tag,
 )
 from async_pixiv.model.user import User
-from pydantic import (
-    AnyHttpUrl,
-    Field,
-)
-from typing_extensions import Literal
-from yarl import URL
 
 try:
     import imageio
 except ImportError:
     imageio = None
 
+try:
+    import regex as re
+except ImportError:
+    import re
+
 if TYPE_CHECKING:
     from async_pixiv.client import PixivClient
     from async_pixiv.model.result import (
@@ -57,6 +65,8 @@ UGOIRA_RESULT_TYPE = (
     Literal['zip', 'jpg', 'all', 'iter']
 )
 
+session = Session()
+
 
 class ArtWorkType(Enum):
     illust = 'illust'
@@ -107,6 +117,9 @@ class ArtWork(PixivModel):
     is_muted: bool
     total_comments: Optional[int]
     comment_access_control: Optional[int]
+    ai_type: AIType = Field(alias='illust_ai_type')
+
+    _is_r18: Optional[bool] = PrivateAttr(None)
 
     @property
     def is_nsfw(self) -> bool:
@@ -114,14 +127,18 @@ class ArtWork(PixivModel):
 
     @property
     def is_r18(self) -> bool:
-        return (
-            ArkoWrapper(self.tags)
-            .map(lambda x: x.name)
-            .append(self.title)
-            .map(lambda x: x.upper().replace('-', ''))
-            .map(lambda x: 'R18' in x)
-            .any()
-        )
+        if self._is_r18 is None:
+            from async_pixiv.client import PixivClient
+
+            client = PixivClient.get_client()
+            response = client.sync_request('GET', str(self.link))
+            html = response.text
+            title = re.findall(
+                r"<meta property=\"twitter:title\" content=\"(.*?)\">",
+                html
+            )[0]
+            self._is_r18 = bool(re.findall(r"\[R-18]", title))
+        return self._is_r18
 
     @property
     def link(self) -> URL:
